@@ -3,6 +3,7 @@
 from .fs_utils import find_path_by_leaf
 from .hex_file_utils import read_hex_file, read_hex_file_as_ints
 from .repo_utils import get_git_repo_root, is_path_writeable, make_repo_root_relpath_into_abs
+from .dir_walker import DirWalker
 
 __all__ = [
     "find_path_by_leaf",
@@ -11,5 +12,6 @@ __all__ = [
     "get_git_repo_root",
     "is_path_writeable",
     "make_repo_root_relpath_into_abs",
+    "DirWalker",
 ]
 
